#---
# Excerpted from "Rails Test Prescriptions",
# published by The Pragmatic Bookshelf.
# Copyrights apply to this code. It may not be used to create training material, 
# courses, books, articles, and the like. Contact us if you are in doubt.
# We make no guarantees that this code is fit for any purpose. 
# Visit http://www.pragmaticprogrammer.com/titles/nrtest for more book information.
#---
require 'spec_helper'

describe StatusReportsController do

  def mock_status_report(stubs={})
    @mock_status_report ||= mock_model(StatusReport, stubs).as_null_object
  end

  describe "GET index" do
    it "assigns all status_reports as @status_reports" do
      StatusReport.stub(:all) { [mock_status_report] }
      get :index
      assigns(:status_reports).should eq([mock_status_report])
    end
  end

  describe "GET show" do
    it "assigns the requested status_report as @status_report" do
      StatusReport.stub(:find).with("37") { mock_status_report }
      get :show, :id => "37"
      assigns(:status_report).should be(mock_status_report)
    end
  end

  describe "GET new" do
    it "assigns a new status_report as @status_report" do
      StatusReport.stub(:new) { mock_status_report }
      get :new
      assigns(:status_report).should be(mock_status_report)
    end
  end

  describe "GET edit" do
    it "assigns the requested status_report as @status_report" do
      StatusReport.stub(:find).with("37") { mock_status_report }
      get :edit, :id => "37"
      assigns(:status_report).should be(mock_status_report)
    end
  end

  describe "POST create" do

    describe "with valid params" do
      it "assigns a newly created status_report as @status_report" do
        StatusReport.stub(:new_from_params).with({'these' => 'params'}) { 
            mock_status_report(:save => true) }
        post :create, :status_report => {'these' => 'params'}
        assigns(:status_report).should be(mock_status_report)
      end


      it "redirects to the created status_report" do
        StatusReport.stub(:new) { mock_status_report(:save => true) }
        post :create, :status_report => {}
        response.should redirect_to(status_report_url(mock_status_report))
      end
    end
    
    

    describe "with invalid params" do
      it "assigns a newly created but unsaved status_report as @status_report" do
        StatusReport.stub(:new).with({'these' => 'params'}) { mock_status_report(:save => false) }
        post :create, :status_report => {'these' => 'params'}
        assigns(:status_report).should be(mock_status_report)
      end

      it "re-renders the 'new' template" do
        StatusReport.stub(:new) { mock_status_report(:save => false) }
        post :create, :status_report => {}
        response.should render_template("new")
      end
    end

  end

  describe "PUT update" do

    describe "with valid params" do
      it "updates the requested status_report" do
        StatusReport.should_receive(:find).with("37") { mock_status_report }
        mock_status_report.should_receive(:update_attributes).with({'these' => 'params'})
        put :update, :id => "37", :status_report => {'these' => 'params'}
      end

      it "assigns the requested status_report as @status_report" do
        StatusReport.stub(:find) { mock_status_report(:update_attributes => true) }
        put :update, :id => "1"
        assigns(:status_report).should be(mock_status_report)
      end

      it "redirects to the status_report" do
        StatusReport.stub(:find) { mock_status_report(:update_attributes => true) }
        put :update, :id => "1"
        response.should redirect_to(status_report_url(mock_status_report))
      end
    end

    describe "with invalid params" do
      it "assigns the status_report as @status_report" do
        StatusReport.stub(:find) { mock_status_report(:update_attributes => false) }
        put :update, :id => "1"
        assigns(:status_report).should be(mock_status_report)
      end

      it "re-renders the 'edit' template" do
        StatusReport.stub(:find) { mock_status_report(:update_attributes => false) }
        put :update, :id => "1"
        response.should render_template("edit")
      end
    end

  end

  describe "DELETE destroy" do
    it "destroys the requested status_report" do
      StatusReport.should_receive(:find).with("37") { mock_status_report }
      mock_status_report.should_receive(:destroy)
      delete :destroy, :id => "37"
    end

    it "redirects to the status_reports list" do
      StatusReport.stub(:find) { mock_status_report }
      delete :destroy, :id => "1"
      response.should redirect_to(status_reports_url)
    end
  end

end
